@@ -15,7 +15,7 @@ for _ in _:
     ___
 '''
 """
-`codder.mast` pattern for simple `for` loop.
+`potluck.mast` pattern for simple `for` loop.
 """
 
 
@@ -27,14 +27,14 @@ else:
     ___
 '''
 """
-`codder.mast` pattern for a `for` loop with an `else` clause.
+`potluck.mast` pattern for a `for` loop with an `else` clause.
 """
 
 
 # Both of the above...
 ALL_FOR_PATTERNS = [ FOR_PATTERN, FOR_ELSE_PATTERN ]
 """
-`codder.mast` patterns for all `for` loop variants.
+`potluck.mast` patterns for all `for` loop variants.
 """
 
 
@@ -44,7 +44,7 @@ while _:
     ___
 '''
 """
-A `codder.mast` pattern for a simple `while` loop.
+A `potluck.mast` pattern for a simple `while` loop.
 """
 
 
@@ -56,14 +56,14 @@ else:
     ___
 '''
 """
-A `codder.mast` pattern for `while`/`else`.
+A `potluck.mast` pattern for `while`/`else`.
 """
 
 
 # Both of the above...
 ALL_WHILE_PATTERNS = [ WHILE_PATTERN, WHILE_ELSE_PATTERN ]
 """
-`codder.mast` patterns for all `while` loop variants.
+`potluck.mast` patterns for all `while` loop variants.
 """
 
 
@@ -72,7 +72,7 @@ SIMPLE_COMPREHENSION_PATTERN = '''
 [ _ for _ in _ ]
 '''
 """
-A `codder.mast` pattern for a single for loop comprehension without a filter.
+A `potluck.mast` pattern for a single for loop comprehension without a filter.
 """
 
 
@@ -80,7 +80,7 @@ FILTER_COMPREHENSION_PATTERN = '''
 [ _ for _ in _ if _ ]
 '''
 """
-A `codder.mast` pattern for a single for loop comprehension with a filter.
+A `potluck.mast` pattern for a single for loop comprehension with a filter.
 """
 
 
@@ -88,7 +88,7 @@ DOUBLE_COMPREHENSION_PATTERN = '''
 [ _ for _ in _ for _ in _ ]
 '''
 """
-A `codder.mast` pattern for a double for loop comprehension without a filter.
+A `potluck.mast` pattern for a double for loop comprehension without a filter.
 """
 
 
@@ -96,7 +96,7 @@ DOUBLE_FILTER_COMPREHENSION_PATTERN = '''
 [ _ for _ in _ for _ in _ if _ ]
 '''
 """
-A `codder.mast` pattern for a double for loop comprehension with a filter.
+A `potluck.mast` pattern for a double for loop comprehension with a filter.
 """
 
 
@@ -104,7 +104,7 @@ TRIPLE_COMPREHENSION_PATTERN = '''
 [ _ for _ in _ for _ in _ for _ in _ ]
 '''
 """
-A `codder.mast` pattern for a triple for loop comprehension without a filter.
+A `potluck.mast` pattern for a triple for loop comprehension without a filter.
 """
 
 
@@ -112,7 +112,7 @@ TRIPLE_FILTER_COMPREHENSION_PATTERN = '''
 [ _ for _ in _ for _ in _ for _ in _ if _ ]
 '''
 """
-A `codder.mast` pattern for a triple for loop comprehension with a filter.
+A `potluck.mast` pattern for a triple for loop comprehension with a filter.
 """
 
 
@@ -125,7 +125,7 @@ ALL_REASONABLE_COMPREHENSION_PATTERNS = [
     TRIPLE_FILTER_COMPREHENSION_PATTERN,
 ]
 """
-`codder.mast` patterns for single, double, and triple list comprehensions
+`potluck.mast` patterns for single, double, and triple list comprehensions
 with and without filtering.
 
 Note: does not include dictionary comprehensions (TODO: that?)
@@ -137,14 +137,14 @@ We will simply hope that students do not use quadruple comprehensions...
 # Combination patterns for loops and loops + comprehensions
 ALL_FOR_AND_WHILE_LOOP_PATTERNS = ALL_FOR_PATTERNS + ALL_WHILE_PATTERNS
 """
-`codder.mast` patterns for all while/for loop variants.
+`potluck.mast` patterns for all while/for loop variants.
 """
 ALL_LOOP_AND_COMPREHENSION_PATTERNS = (
     ALL_FOR_AND_WHILE_LOOP_PATTERNS
   + ALL_REASONABLE_COMPREHENSION_PATTERNS
 )
 """
-`codder.mast` patterns for all reasonable loop/comprehension types,
+`potluck.mast` patterns for all reasonable loop/comprehension types,
 although highly-nested comprehensions are not included.
 """
 ALL_SINGLE_LOOP_AND_COMPREHENSION_PATTERNS = (
@@ -154,7 +154,7 @@ ALL_SINGLE_LOOP_AND_COMPREHENSION_PATTERNS = (
     ]
 )
 """
-`codder.mast` patterns for all loop/comprehension patterns that are
+`potluck.mast` patterns for all loop/comprehension patterns that are
 single loops.
 """
 
@@ -202,7 +202,7 @@ METHOD_CALL_PATTERNS = [
 ]
 """
 Patterns for method calls specifically. Note that the
-FUNCTION_CALL_PATTERNS will find method calls too, but will bind 'f' as
+`FUNCTION_CALL_PATTERNS` will find method calls too, but will bind 'f' as
 the entire object + method expression, whereas these patterns will bind
 'f' as the method name (multiple bindings will result from chained method
 calls).
@@ -220,15 +220,14 @@ def function_def_patterns(fn_name, args_pattern=None):
     it should be a string containing mast code that goes between the
     parentheses of a function definition. For example:
 
-        "_, _"
-            There must be exactly two arguments.
-        "___, x=3"
-            There may be any number of positional arguments, and
-            there must be a single keyword argument named 'x' with
-            default value 3.
-        "one, two"
-            There must be exactly two arguments and they must be
-            named 'one' and 'two'.
+    - `"_, _"`
+        There must be exactly two arguments.
+    - `"___, x=3"`
+        There may be any number of positional arguments, and there must
+        be a single keyword argument named 'x' with default value 3.
+    - `"one, two"`
+        There must be exactly two arguments and they must be named 'one'
+        and 'two'.
 
     The args_pattern may also be a list of strings and any of those
     alternatives will be accepted, or it may be an integer, in which case
